--filter=-linelength,-readability/mixedcase CMakeLists.txt
1
89
CMakeLists.txt:31: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:36: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:47: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:58: Tab found; please use spaces [whitespace/tabs]
CMakeLists.txt:60: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:80: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:85: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:93: Extra spaces between 'elseif' and its () [whitespace/extra]
CMakeLists.txt:125: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:128: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:181: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:234: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:239: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:261: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:262: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:263: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:338: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:339: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:351: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:352: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:364: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:365: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:397: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:400: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:412: Expression repeated inside endif; better to use only endif() [readability/logic]
CMakeLists.txt:427: Expression repeated inside endif; better to use only endif() [readability/logic]
CMakeLists.txt:428: Expression repeated inside endif; better to use only endif() [readability/logic]
CMakeLists.txt:437: Expression repeated inside endif; better to use only endif() [readability/logic]
CMakeLists.txt:438: Expression repeated inside endif; better to use only endif() [readability/logic]
CMakeLists.txt:452: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:460: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:466: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:482: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:523: Extra spaces between 'option' and its () [whitespace/extra]
CMakeLists.txt:524: Extra spaces between 'option' and its () [whitespace/extra]
CMakeLists.txt:525: Extra spaces between 'option' and its () [whitespace/extra]
CMakeLists.txt:526: Extra spaces between 'option' and its () [whitespace/extra]
CMakeLists.txt:527: Extra spaces between 'option' and its () [whitespace/extra]
CMakeLists.txt:528: Extra spaces between 'option' and its () [whitespace/extra]
CMakeLists.txt:535: Extra spaces between 'option' and its () [whitespace/extra]
CMakeLists.txt:538: Extra spaces between 'option' and its () [whitespace/extra]
CMakeLists.txt:565: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:571: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:582: Tab found; please use spaces [whitespace/tabs]
CMakeLists.txt:592: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:619: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:675: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:677: Extra spaces between 'endif' and its () [whitespace/extra]
CMakeLists.txt:677: Expression repeated inside endif; better to use only endif() [readability/logic]
CMakeLists.txt:678: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:680: Extra spaces between 'endif' and its () [whitespace/extra]
CMakeLists.txt:680: Expression repeated inside endif; better to use only endif() [readability/logic]
CMakeLists.txt:681: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:683: Extra spaces between 'endif' and its () [whitespace/extra]
CMakeLists.txt:683: Expression repeated inside endif; better to use only endif() [readability/logic]
CMakeLists.txt:701: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:824: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:834: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:841: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:846: Expression repeated inside endif; better to use only endif() [readability/logic]
CMakeLists.txt:857: Expression repeated inside endif; better to use only endif() [readability/logic]
CMakeLists.txt:860: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:861: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:862: Expression repeated inside endif; better to use only endif() [readability/logic]
CMakeLists.txt:872: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:872: Mismatching spaces inside () after command [whitespace/mismatch]
CMakeLists.txt:906: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:913: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:940: Do not use mixed case commands [readability/wonkycase]
CMakeLists.txt:953: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:966: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:968: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:984: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:991: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:995: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:1022: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:1034: Expression repeated inside endif; better to use only endif() [readability/logic]
CMakeLists.txt:1041: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:1043: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:1044: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:1051: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:1053: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:1054: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:1062: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:1096: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:1097: Weird indentation; use 2 spaces [whitespace/indent]
CMakeLists.txt:1103: Extra spaces between 'if' and its () [whitespace/extra]
CMakeLists.txt:1107: Extra spaces between 'if' and its () [whitespace/extra]

Total Errors: 88

