src/CMakeLists.txt
1
353
src/CMakeLists.txt:30: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:38: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:121: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:201: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:206: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:207: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:208: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:209: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:211: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:213: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:215: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:218: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:223: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:224: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:225: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:230: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:231: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:232: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:234: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:234: Mismatching spaces inside () after command [whitespace/mismatch]
src/CMakeLists.txt:236: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:241: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:244: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:245: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:252: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:256: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:260: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:263: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:264: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:272: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:274: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:279: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:280: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:281: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:282: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:286: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:287: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:304: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:309: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:310: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:311: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:318: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:319: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:320: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:324: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:328: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:331: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:333: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:342: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:343: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:347: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:351: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:355: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:365: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:367: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:368: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:370: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:371: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:373: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:378: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:382: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:384: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:388: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:391: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:392: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:397: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:404: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:407: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:408: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:410: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:415: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:421: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:422: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:423: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:434: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:441: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:445: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:449: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:452: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:459: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:460: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:471: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:472: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:473: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:474: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:484: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:494: Do not use mixed case commands [readability/wonkycase]
src/CMakeLists.txt:500: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:505: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:524: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:525: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:525: Mismatching spaces inside () after command [whitespace/mismatch]
src/CMakeLists.txt:527: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:529: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:535: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:537: Mismatching spaces inside () after command [whitespace/mismatch]
src/CMakeLists.txt:539: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:540: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:555: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:558: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:561: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:564: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:571: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:571: Weird indentation; use 2 spaces [whitespace/indent]
src/CMakeLists.txt:572: Weird indentation; use 2 spaces [whitespace/indent]
src/CMakeLists.txt:583: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:587: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:589: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:592: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:633: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:648: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:659: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:669: Weird indentation; use 2 spaces [whitespace/indent]
src/CMakeLists.txt:715: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:732: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:733: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:740: Extra spaces between 'if' and its () [whitespace/extra]
src/CMakeLists.txt:741: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:756: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:757: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:779: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:815: Extra spaces between 'if' and its () [whitespace/extra]
src/CMakeLists.txt:818: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:820: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:821: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:823: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:824: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:826: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:832: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:833: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:937: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:969: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:971: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1038: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1045: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1053: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1056: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1062: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1063: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1075: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1096: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1108: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1152: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1170: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1173: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1183: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1201: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1256: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1302: Weird indentation; use 2 spaces [whitespace/indent]
src/CMakeLists.txt:1303: Weird indentation; use 2 spaces [whitespace/indent]
src/CMakeLists.txt:1307: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1311: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1326: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1327: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1331: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1338: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1342: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1345: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1353: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1358: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1362: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1372: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1373: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1374: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1374: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1375: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1375: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1376: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1377: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1378: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1378: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1379: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1379: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1380: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1380: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1381: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1381: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1382: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1383: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1383: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1384: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1385: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1386: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1387: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1387: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1388: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1389: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1389: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1390: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1391: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1392: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1393: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1397: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1402: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1402: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1403: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1403: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1408: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1412: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1415: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1415: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1418: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1419: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1419: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1420: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1420: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1421: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1422: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1422: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1423: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1423: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1424: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1424: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1425: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1426: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1426: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1427: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1427: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1428: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1428: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1429: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1429: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1430: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1430: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1431: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1431: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1432: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1432: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1433: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1434: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1434: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1435: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1439: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1439: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1444: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1445: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1445: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1449: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1450: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1450: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1451: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1451: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1455: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1455: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1456: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1456: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1457: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1457: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1458: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1458: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1459: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1459: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1460: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1460: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1461: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1461: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1463: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1463: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1464: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1464: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1465: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1465: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1467: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1468: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1468: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1472: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1472: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1478: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1479: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1479: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1480: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1480: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1481: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1481: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1482: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1482: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1483: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1483: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1484: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1484: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1485: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1485: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1486: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1486: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1488: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1489: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1489: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1490: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1490: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1491: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1491: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1492: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1492: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1493: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1493: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1494: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1494: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1497: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1498: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1501: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1501: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1502: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1502: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1504: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1504: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1505: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1505: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1506: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1506: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1507: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1507: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1508: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1508: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1509: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1509: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1510: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1511: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1511: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1513: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1513: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1514: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1514: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1515: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1515: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1516: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1516: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1517: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1517: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1518: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1518: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1519: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1519: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1523: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1524: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1525: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1525: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1527: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1528: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1528: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1529: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1529: Do not mix upper and lower case commands [readability/mixedcase]
src/CMakeLists.txt:1532: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1533: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1544: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1555: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1563: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1564: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1588: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1589: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1592: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1614: Lines should be <= 80 characters long [linelength]
src/CMakeLists.txt:1628: Lines should be <= 80 characters long [linelength]

Total Errors: 352

